import { Menu } from "@islands/KMenu/types.ts";
import { addMovieInfos } from "@islands/KMenu/commands/add_movie_infos.ts";
import { createNewMovie } from "@islands/KMenu/commands/create_movie.ts";
import { createNewArticle } from "@islands/KMenu/commands/create_article.ts";
import { getCookie } from "@lib/string.ts";

export const menus: Record<string, Menu> = {
  main: {
    title: "Run",
    entries: [
      {
        title: "Clear Cache",
        icon: "IconRefresh",
        cb: async (state) => {
          state.activeState.value = "loading";
          await fetch("/api/cache", {
            method: "DELETE",
          });
          state.activeState.value = "normal";
          state.visible.value = false;
        },
        visible: () => {
          if (!getCookie("session_cookie")) return false;
          return true;
        },
      },
      {
        title: "Login",
        icon: "IconLogin",
        cb: () => {
          window.location.pathname = "/api/auth/login";
        },
        visible: () => {
          return !getCookie("session_cookie");
        },
      },
      {
        title: "Search",
        icon: "IconSearch",
        cb: () => {
          window.location.href += "?q=";
        },
        visible: () => {
          return !!getCookie("session_cookie") && window.location.search === "";
        },
      },
      {
        title: "Logout",
        icon: "IconLogout",
        cb: () => {
          window.location.pathname = "/api/auth/logout";
        },
        visible: () => {
          return !!getCookie("session_cookie");
        },
      },
      createNewArticle,
      createNewMovie,
      addMovieInfos,
    ],
  },
};
