import { Handlers, PageProps } from "$fresh/server.ts";
import { RecipeCard } from "@components/RecipeCard.tsx";
import { MainLayout } from "@components/layouts/main.tsx";
import { getAllRecipes, Recipe } from "@lib/resource/recipes.ts";
import { Grid } from "@components/Grid.tsx";
import { IconArrowLeft } from "@components/icons.tsx";
import { KMenu } from "@islands/KMenu.tsx";
import { RedirectSearchHandler } from "@islands/Search.tsx";

export const handler: Handlers<Recipe[] | null> = {
  async GET(_, ctx) {
    const recipes = await getAllRecipes();
    return ctx.render(recipes);
  },
};

export default function Greet(props: PageProps<Recipe[] | null>) {
  return (
    <MainLayout url={props.url} title="Recipes" context={{ type: "recipe" }}>
      <RedirectSearchHandler />
      <KMenu type="main" context={{ type: "recipe" }} />
      <header class="flex gap-4 items-center mb-2 lg:mb-5 md:hidden">
        <a
          class="px-4 lg:ml-4 py-2 bg-gray-300 text-gray-800 rounded-lg flex items-center gap-1"
          href="/"
        >
          <IconArrowLeft class="w-5 h-5" />
          Back
        </a>

        <h3 class="text-2xl text-white font-light">🍽️ Recipes</h3>
      </header>
      <Grid>
        {props.data?.map((doc) => {
          return <RecipeCard recipe={doc} />;
        })}
      </Grid>
    </MainLayout>
  );
}
