import { Handlers, PageProps } from "$fresh/server.ts";
import { MainLayout } from "@components/layouts/main.tsx";
import { RecipeHero } from "@components/RecipeHero.tsx";
import { HashTags } from "@components/HashTags.tsx";
import { renderMarkdown } from "@lib/documents.ts";
import { getSeries, Series } from "@lib/resource/series.ts";
import { RedirectSearchHandler } from "@islands/Search.tsx";
import { KMenu } from "@islands/KMenu.tsx";

export const handler: Handlers<Series | null> = {
  async GET(_, ctx) {
    const movie = await getSeries(ctx.params.name);
    return ctx.render(movie);
  },
};

export default function Greet(props: PageProps<Series>) {
  const serie = props.data;

  const { author = "", date = "" } = serie.meta;

  const content = renderMarkdown(serie.description || "");

  return (
    <MainLayout url={props.url} title={`Serie > ${serie.name}`} context={serie}>
      <RedirectSearchHandler />
      <KMenu type="main" context={serie} />
      <RecipeHero
        data={serie}
        subline={[author, date.toString()]}
        editLink={`https://notes.max-richter.dev/Media/series/${serie.id}`}
        backlink="/series"
      />
      {serie.tags.length > 0 && (
        <>
          <br />
          <HashTags tags={serie.tags} />
        </>
      )}
      <div class="px-8 text-white mt-10">
        {serie?.description?.length > 80
          ? <h2 class="text-4xl font-bold mb-4">Review</h2>
          : <></>}
        <pre
          class="whitespace-break-spaces"
          dangerouslySetInnerHTML={{ __html: content || "" }}
        >
          {content}
        </pre>
      </div>
    </MainLayout>
  );
}
